@@ -21,6 +21,9 @@ sub run {
   local $SIG{INT} = local $SIG{TERM} = sub { $self->{finished}++ };
   local $SIG{QUIT}
     = sub { ++$self->{finished} and kill 'KILL', keys %{$self->{jobs}} };
+  local $SIG{TTIN} = sub { $self->{max}++ };
+  local $SIG{TTOU} = sub { $self->{max}-- if $self->{max} > 0 };
+  local $SIG{USR1} = sub { $self->{max} = 0 };
 
   # Log fatal errors
   my $app = $self->app;
@@ -114,6 +117,20 @@ Stop gracefully after finishing the current jobs.
 
 Stop immediately without finishing the current jobs.
 
+=head2 TTIN
+
+Increase the number of jobs to perform concurrently by one.
+
+=head2 TTOU
+
+Decrease the number of jobs to perform concurrently by one.
+
+=head2 USR1
+
+Pause the worker by setting the number of jobs to perform concurrently to zero.
+That means it will finish all current jobs, but not accept new ones, until the
+number is increased again with L</"TTIN">.
+
 =head1 ATTRIBUTES
 
 L<Minion::Command::minion::worker> inherits all attributes from
